==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/WebhookConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class WebhookConfigBuilder extends io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluentImpl<io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfig,io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigBuilder>{
  public WebhookConfigBuilder() {
    this(false);
  }
  public WebhookConfigBuilder(java.lang.Boolean validationEnabled) {
    this(new WebhookConfig(), validationEnabled);
  }
  public WebhookConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public WebhookConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new WebhookConfig(), validationEnabled);
  }
  public WebhookConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfig instance) {
    this(fluent, instance, false);
  }
  public WebhookConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withHttpConfig(instance.getHttpConfig()); 
    fluent.withMaxAlerts(instance.getMaxAlerts()); 
    fluent.withSendResolved(instance.getSendResolved()); 
    fluent.withUrl(instance.getUrl()); 
    fluent.withUrlSecret(instance.getUrlSecret()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public WebhookConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfig instance) {
    this(instance,false);
  }
  public WebhookConfigBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfig instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withHttpConfig(instance.getHttpConfig()); 
    this.withMaxAlerts(instance.getMaxAlerts()); 
    this.withSendResolved(instance.getSendResolved()); 
    this.withUrl(instance.getUrl()); 
    this.withUrlSecret(instance.getUrlSecret()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfigFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.WebhookConfig build() {
    WebhookConfig buildable = new WebhookConfig(fluent.getHttpConfig(),fluent.getMaxAlerts(),fluent.getSendResolved(),fluent.getUrl(),fluent.getUrlSecret());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    WebhookConfigBuilder that = (WebhookConfigBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-6.6.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/WebhookConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class WebhookConfigBuilder extends WebhookConfigFluentImpl<WebhookConfigBuilder> implements VisitableBuilder<WebhookConfig,WebhookConfigBuilder>{
  public WebhookConfigBuilder() {
    this(false);
  }
  public WebhookConfigBuilder(Boolean validationEnabled) {
    this(new WebhookConfig(), validationEnabled);
  }
  public WebhookConfigBuilder(WebhookConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public WebhookConfigBuilder(WebhookConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new WebhookConfig(), validationEnabled);
  }
  public WebhookConfigBuilder(WebhookConfigFluent<?> fluent,WebhookConfig instance) {
    this(fluent, instance, false);
  }
  public WebhookConfigBuilder(WebhookConfigFluent<?> fluent,WebhookConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withHttpConfig(instance.getHttpConfig()); 
    fluent.withMaxAlerts(instance.getMaxAlerts()); 
    fluent.withSendResolved(instance.getSendResolved()); 
    fluent.withUrl(instance.getUrl()); 
    fluent.withUrlSecret(instance.getUrlSecret()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public WebhookConfigBuilder(WebhookConfig instance) {
    this(instance,false);
  }
  public WebhookConfigBuilder(WebhookConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withHttpConfig(instance.getHttpConfig()); 
    this.withMaxAlerts(instance.getMaxAlerts()); 
    this.withSendResolved(instance.getSendResolved()); 
    this.withUrl(instance.getUrl()); 
    this.withUrlSecret(instance.getUrlSecret()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  WebhookConfigFluent<?> fluent;
  Boolean validationEnabled;
  public WebhookConfig build() {
    WebhookConfig buildable = new WebhookConfig(fluent.getHttpConfig(),fluent.getMaxAlerts(),fluent.getSendResolved(),fluent.getUrl(),fluent.getUrlSecret());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
